<div id="top"></div>

<h1 align="center">jptranstokenizer: Japanese Tokenzier for transformers</h1>

<p align="center">
  <img alt="Python" src="https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue">
  <a href="https://img.shields.io/pypi/v/jptranstokenizer.svg">
    <img alt="pypi" src="https://pypi.python.org/pypi/jptranstokenizer">
  </a>
  <a href="https://github.com/retarfi/jptranstokenizer#licenses">
    <img alt="GitHub" src="https://img.shields.io/badge/license-Apache--2.0-brightgreen">
  </a>
  <a href="https://github.com/retarfi/jptranstokenizer/releases">
    <img alt="GitHub release" src="https://img.shields.io/github/v/release/retarfi/jptranstokenizer.svg">
  </a>
</p>

**issue は日本語でも大丈夫です。**